pub enum KeyState {
Revoked,
Retired,
Active,
}Expand description
Lifecycle state of a signing key.
Variants
Revoked
Key has been revoked and must not be used.
Retired
Key has been retired (graceful end-of-life).
Active
Key is currently active and may be used for signing.