pub struct DoctrineState {
pub rule: String,
pub source_principle_id: String,
pub force: DoctrineForce,
pub truth_state: TruthState,
}Expand description
Semantic state of one doctrine entry in a snapshot.
Fields
rule: StringDoctrine rule text.
source_principle_id: StringId of the principle that generated this doctrine entry.
force: DoctrineForceEnforcement strength of this doctrine entry.
truth_state: TruthStateCurrent truth classification.