pub struct SemanticDiff {
pub current_snapshot_id: Option<String>,
pub restored_snapshot_id: Option<String>,
pub changes: Vec<SemanticChange>,
}Expand description
Full semantic diff from current state to candidate restored state.
Fields
current_snapshot_id: Option<String>Snapshot id of the pre-restore (current) state.
restored_snapshot_id: Option<String>Snapshot id of the candidate restored state.
changes: Vec<SemanticChange>Ordered list of semantic changes detected.
Implementations
Sourceimpl SemanticDiff
impl SemanticDiff
Sourcepub fn between(current: &SemanticSnapshot, restored: &SemanticSnapshot) -> Self
pub fn between(current: &SemanticSnapshot, restored: &SemanticSnapshot) -> Self
Compute the diff between current and restored snapshots.
Sourcepub fn severity(&self) -> SemanticSeverity
pub fn severity(&self) -> SemanticSeverity
Returns the highest severity across all changes, or Clean when there are none.
Sourcepub fn restore_decision(&self, recovery_acknowledged: bool) -> RestoreDecision
pub fn restore_decision(&self, recovery_acknowledged: bool) -> RestoreDecision
Derives a restore decision from this diff given the operator’s acknowledgement flag.