RollbackForkState

Struct RollbackForkState 

pub struct RollbackForkState {
    pub schema_version: Option<u16>,
    pub fork_marker: Option<ForkMarker>,
}
Rollback/fork metadata available to a caller that is comparing current state against a candidate state before permitting restore, doctor, or write flows.

Fields

schema_version: Option<u16>

Declared schema version for the state, if the caller has one.

fork_marker: Option<ForkMarker>

Explicit fork marker detected in metadata or state, if any.