pub struct ForkMarker {
pub marker: String,
}Expand description
Explicit marker that state belongs to, or is attempting to enter, a forked lineage.
Fields
marker: StringStable marker value from the metadata source that found it.
Implementations